=================
Battleship Python
=================

|PyPI latest| |PyPI Version| |PyPI License|  |Travis Build Status| |Coverage|


This is a simple, but super cool Battleship game. Lets Play!!!


Installation
------------

.. code-block:: bash

   $ pip install py-battleship

Or, you can download the source and

.. code-block:: bash

   $ git clone git@github.com:rhenter/battleship-python.git
   $ cd battleship-python
   $ python setup.py install

Add sudo in the beginning if you met problem.


How to Use
----------

To play use py-battleship or python -m battlefield

.. image:: docs/images/game.png
   :width: 600

Documentation
-------------

    In progress


Contributing
------------

Please send pull requests, very much appreciated.


1. Fork the `repository <https://github.com/rhenter/battleship-python>`_ on GitHub.
2. Make a branch off of master and commit your changes to it.
3. Install requirements. ``pip install -r requirements-dev.txt``
4. Install pre-commit. ``pre-commit install``
5. Create a Pull Request with your contribution



.. |PyPI Version| image:: https://img.shields.io/pypi/pyversions/py-battleship.svg?maxAge=360
   :target: https://pypi.python.org/pypi/py-battleship
.. |PyPI License| image:: https://img.shields.io/pypi/l/py-battleship.svg?maxAge=360
   :target: https://github.com/rhenter/battleship-python/blob/master/LICENSE
.. |PyPI latest| image:: https://img.shields.io/pypi/v/py-battleship.svg?maxAge=360
   :target: https://pypi.python.org/pypi/py-battleship
.. |Travis Build Status| image:: https://api.travis-ci.org/rhenter/battleship-python.png?branch=master
   :target: https://travis-ci.org/rhenter/battleship-python
.. |Coverage| image:: https://codecov.io/gh/rhenter/battleship-python/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/rhenter/battleship-python

